==> LinHES-config-8.5.1-2-x86_64.pkg.tar.xz: usr/MythVantage/bin/restore_km_db_chroot.sh <==
#!/bin/bash
. /etc/profile
. /etc/systemconfig
. $MV_ROOT/bin/install_functions.sh

myhost=$hostname
hostname $myhost
mount -t proc none /proc
DBFILE=$1

if  [ $SystemType = "Master_backend" -o $SystemType = "Standalone"  ]
    then
        #restore database
        pacman --noconfirm -S --force mysql
        status=1
        mysqlstatus=1
        while [ ! $status = 0  ]
        do
            /etc/rc.d/mysqld stop
            sleep 1
            /etc/rc.d/mysqld start
            mysqlstatus=$?
            if [ $mysqlstatus = 0 ]
            then
                mysql -e "show databases;"
                showstatus=$?
                if [ $showstatus = 0 ]
                then
                   #load database
                   pacman --noconfirm -R mythdb-initial
                   pacman --noconfirm  -S mythdb-initial

                   if [ -f $DBFILE ]
                   then
                        echo "restoring old database"
                        gunzip -c $DBFILE > /tmp/mythconverg.sql
                        mysql  mythconverg < /tmp/mythconverg.sql
                        update_db_settings HostServiceMythWEB "1"
                        echo 'UseMythWEB="1"' >> /etc/systemconfig
                   else
                        echo "Could not restore old database, mythconverg.sql is missing."
                        touch /tmp/.upgrade_db_failed
                   fi

                    if [ -d /data/srv/mysql/mythconverg ]
                    then
                        status=0
                    fi
                fi
            fi
        done
        rm -f /tmp/mythconverg.sql
    else
        exit 0
    fi

#/etc/rc.d/mysqld stop
#umount /proc

==> LinHES-config-8.7.0-1-x86_64.pkg.tar.xz: usr/MythVantage/bin/restore_km_db_chroot.sh <==
#!/bin/bash
. /etc/profile
. /etc/systemconfig
. $MV_ROOT/bin/install_functions.sh

myhost=$hostname
hostname $myhost
mount -t proc none /proc
DBFILE=$1

if  [ $SystemType = "Master_backend" -o $SystemType = "Standalone"  ]
    then
        #restore database
        pacman --noconfirm -S mysql
        status=1
        mysqlstatus=1
        while [ ! $status = 0  ]
        do
            /etc/rc.d/mysqld stop
            sleep 1
            /etc/rc.d/mysqld start
            mysqlstatus=$?
            if [ $mysqlstatus = 0 ]
            then
                mysql -e "show databases;"
                showstatus=$?
                if [ $showstatus = 0 ]
                then
                   #load database
                   pacman --noconfirm -R mythdb-initial
                   pacman --noconfirm  -S mythdb-initial

                   if [ -f $DBFILE ]
                   then
                        echo "restoring old database"
                        gunzip -c $DBFILE > /tmp/mythconverg.sql
                        mysql  mythconverg < /tmp/mythconverg.sql
                        update_db_settings HostServiceMythWEB "1"
                        echo 'UseMythWEB="1"' >> /etc/systemconfig
                   else
                        echo "Could not restore old database, mythconverg.sql is missing."
                        touch /tmp/.upgrade_db_failed
                   fi

                    if [ -d /data/srv/mysql/mythconverg ]
                    then
                        status=0
                    fi
                fi
            fi
        done
        rm -f /tmp/mythconverg.sql
    else
        exit 0
    fi

#/etc/rc.d/mysqld stop
#umount /proc
